@@ -1,3 +1,4 @@
+# nolint start
 #' Color Palettes Few "Show Me the Numbers"
 #'
 #' Qualitative color palettes from Stephen Few (2012)
@@ -23,12 +24,15 @@
 #' @param palette One of \Sexpr[results=rd]{names(ggthemes:::rd_optlist(ggthemes::ggthemes_data$few$colors))}
 #' @family colour few
 #' @example inst/examples/ex-few_pal.R
+# nolint end
 few_pal <- function(palette = "Medium") {
   palette <- ggthemes::ggthemes_data$few$colors[[palette]]
   if (is.null(palette)) {
-    stop("palette must be one of: ",
-         paste0("\"", names(ggthemes::ggthemes_data$few$colors),
-                "\"", collapse = ", "), call. = FALSE)
+    stop(
+      "palette must be one of: ",
+      paste0("\"", names(ggthemes::ggthemes_data$few$colors), "\"", collapse = ", "),
+      call. = FALSE
+    )
   }
   ## The first value, gray, is used for non-data parts.
   values <- palette[["value"]]
@@ -55,7 +59,7 @@ few_pal <- function(palette = "Medium") {
 #' @rdname scale_few
 #' @export
 scale_colour_few <- function(palette = "Medium", ...) {
-    discrete_scale("colour", "few", few_pal(palette), ...)
+  discrete_scale("colour", palette = few_pal(palette), ...)
 }
 
 #' @export
@@ -65,7 +69,7 @@ scale_color_few <- scale_colour_few
 #' @export
 #' @rdname scale_few
 scale_fill_few <- function(palette = "Light", ...) {
-    discrete_scale("fill", "few", few_pal(palette), ...)
+  discrete_scale("fill", palette = few_pal(palette), ...)
 }
 
 #' Theme based on Few's "Practical Rules for Using Color in Charts"
@@ -84,21 +88,21 @@ scale_fill_few <- function(palette = "Light", ...) {
 #' @family themes few
 #' @export
 #' @example inst/examples/ex-theme_few.R
-theme_few <- function(base_size = 12, base_family="") {
-    gray <- "#4D4D4D"
-    black <- "#000000"
-    theme_bw(base_size = base_size, base_family = base_family) +
-        theme(
-              line = element_line(colour = gray),
-              rect = element_rect(fill = "white", colour = NA),
-              text = element_text(colour = black),
-              axis.ticks = element_line(colour = gray),
-              legend.key = element_rect(colour = NA),
-              ## Examples do not use grid lines
-              panel.border = element_rect(colour = gray),
-              panel.grid = element_blank(),
-              strip.background = element_rect(fill = "white", colour = NA)
-            )
+theme_few <- function(base_size = 12, base_family = "") {
+  gray <- "#4D4D4D"
+  black <- "#000000"
+  theme_bw(base_size = base_size, base_family = base_family) +
+    theme(
+      line = element_line(colour = gray),
+      rect = element_rect(fill = "white", colour = NA),
+      text = element_text(colour = black),
+      axis.ticks = element_line(colour = gray),
+      legend.key = element_rect(colour = NA),
+      ## Examples do not use grid lines
+      panel.border = element_rect(colour = gray),
+      panel.grid = element_blank(),
+      strip.background = element_rect(fill = "white", colour = NA)
+    )
 }
 
 #' Shape palette from "Show Me the Numbers" (discrete)
@@ -137,5 +141,5 @@ few_shape_pal <- function() {
 #'   scale uses.
 #' @export
 scale_shape_few <- function(...) {
-  discrete_scale("shape", "few", few_shape_pal(), ...)
+  discrete_scale("shape", palette = few_shape_pal(), ...)
 }
