@@ -21,9 +21,11 @@
 #' @importFrom ggplot2 theme_gray
 theme_igray <- function(base_size = 12, base_family = "") {
   (theme_gray(base_size = base_size, base_family = base_family) +
-     theme(rect = element_rect(fill = "gray90"),
-           legend.key = element_rect(fill = "white"),
-           panel.background = element_rect(fill = "white"),
-           panel.grid.major = element_line(colour = "gray90"),
-           plot.background = element_rect(fill = "gray90")))
+    theme(
+      rect = element_rect(fill = "gray90"),
+      legend.key = element_rect(fill = "white"),
+      panel.background = element_rect(fill = "white"),
+      panel.grid.major = element_line(colour = "gray90"),
+      plot.background = element_rect(fill = "gray90")
+    ))
 }
