@@ -10,6 +10,6 @@ p + geom_tufteboxplot(median.type = "line", hoffset = 0, width = 3)
 # with an offset line for the interquartile range and lines for whiskers
 p + geom_tufteboxplot(median.type = "line")
 # combined with theme_tufte
-p + geom_tufteboxplot() +
-  theme_tufte() +
-  theme(axis.ticks.x = element_blank())
+p + geom_tufteboxplot() + theme_tufte() + theme(axis.ticks.x = element_blank())
+# traditional boxplot with whiskers only out to 1.5 IQR, outlier points
+p + geom_tufteboxplot(stat = "boxplot", outlier.shape = 5)
